clear
close all
clc

u = @(x,y) sin(3.*pi*x).*sin(pi*y);
f = @(x,y) 10*pi^2*sin(3*pi*x).*sin(pi*y) ;
Nsteps = 0;
errors = zeros(1,Nsteps+1);
steps = zeros(1,Nsteps+1);

for p = 2:Nsteps+2
    N = 2^p - 1;
    h = 1/(N+1);
    steps(p) = h;
    % evaluate u and transform into lexicographically ordered vector
    [xh,yh]=meshgrid(linspace(h,1-h,N)); % create mesh using MATLABs meshgrid
    u_eval = u(xh,yh);
    % transform into lexicographically ordered vector
    u_eval = reshape(u_eval',N^2,1);
    
    % get the matrix vector system for problem i with step size N = 2^p-1
    [An, fn] = a11e01getPDE(f, N) ;
    
    alpha = An\fn;
        
    errors(p) = norm(u_eval - alpha, Inf);
end
   
loglog(steps,errors)  
xlabel('h')
ylabel('error')
    
EOCp = (log(errors(2:Nsteps+1)) - log(errors(1:Nsteps)))./...
        (log(steps(2:Nsteps+1)) - log(steps(1:Nsteps)));

